Coverage for src/configuraptor/__init__.py: 100%

1"""

2 Exposes TypedConfig and load_into for this library.

3"""

4

5# SPDX-FileCopyrightText: 2023-present Robin van der Noord <robinvandernoord@gmail.com>

6#

7# SPDX-License-Identifier: MIT

8 from .cls import TypedConfig, TypedMapping, TypedMutableMapping, update

9 from .core import (

10 all_annotations,

11 check_and_convert_data,

12 convert_config,

13 ensure_types,

14 load_into,

15 load_into_class,

16 load_into_instance,

17)

18 from .dump import asdict, asjson, astoml, asyaml

19 from .loaders import register_loader as loader

20 from .postpone import postpone

21 from .singleton import Singleton, SingletonMeta

22 from .type_converters import register_converter as converter

23

24 __all__ = [

25 # cls

26 "TypedConfig",

27 "TypedMapping",

28 "TypedMutableMapping",

29 "update",

30 # singleton

31 "Singleton",

32 "SingletonMeta",

33 # core

34 "all_annotations",

35 "check_and_convert_data",

36 "convert_config",

37 "ensure_types",

38 "load_into",

39 "load_into_class",

40 "load_into_instance",

41 # postpone

42 "postpone",

43 # dump

44 "asdict",

45 "astoml",

46 "asyaml",

47 "asjson",

48 # register

49 "loader",

50 "converter",

51]